@@ -1,6 +1,6 @@
 use darling::FromMeta;
 
-#[derive(Copy, Clone, Debug, FromMeta)]
+#[derive(Clone, Copy, Debug, PartialEq, FromMeta)]
 pub enum Case {
     #[darling(rename = "lowercase")]
     Lower,
@@ -39,17 +39,17 @@ pub enum Case {
 impl Into<convert_case::Case> for Case {
     fn into(self) -> convert_case::Case {
         match self {
-            Case::Lower      => convert_case::Case::Lower,
-            Case::Upper      => convert_case::Case::Upper,
-            Case::Camel      => convert_case::Case::Camel,
-            Case::Pascal     => convert_case::Case::Pascal,
-            Case::Kebab      => convert_case::Case::Kebab,
-            Case::Train      => convert_case::Case::Train,
-            Case::Cobol      => convert_case::Case::Cobol,
-            Case::Snake      => convert_case::Case::Snake,
-            Case::UpperSnake => convert_case::Case::UpperSnake,
-            Case::Flat       => convert_case::Case::Flat,
-            Case::UpperFlat  => convert_case::Case::UpperFlat,
+            Self::Lower      => convert_case::Case::Lower,
+            Self::Upper      => convert_case::Case::Upper,
+            Self::Camel      => convert_case::Case::Camel,
+            Self::Pascal     => convert_case::Case::Pascal,
+            Self::Kebab      => convert_case::Case::Kebab,
+            Self::Train      => convert_case::Case::Train,
+            Self::Cobol      => convert_case::Case::Cobol,
+            Self::Snake      => convert_case::Case::Snake,
+            Self::UpperSnake => convert_case::Case::UpperSnake,
+            Self::Flat       => convert_case::Case::Flat,
+            Self::UpperFlat  => convert_case::Case::UpperFlat,
         }
     }
 }
