@@ -6,8 +6,11 @@ use crate::Case;
 #[darling(attributes(rschema))]
 pub struct StructVariantAttr {
     #[darling(default)]
-    pub additional_properties: bool,
+    pub additional_properties: Option<bool>,
 
     #[darling(default)]
     pub rename_all: Option<Case>,
+
+    #[darling(default)]
+    pub skip: Option<bool>,
 }
